@@ -4,7 +4,7 @@ fn parse_test(c: &mut Criterion) {
     c.bench_function("parse_full", |b| {
         b.iter(|| {
             let s = std::fs::read_to_string("test-conf/fonts.conf").unwrap();
-            fontconfig_parser::parse_document_from_str(&s).unwrap();
+            fontconfig_parser::parse_config_parts(&s).unwrap();
         });
     });
 }
