@@ -1,27 +1,40 @@
-#[cfg(not(feature = "std"))]
-use alloc::string::String;
-
-#[derive(Clone, Debug, Default, PartialEq)]
+#[derive(Clone, Debug, Default, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct Dir {
     pub prefix: DirPrefix,
     pub salt: String,
     pub path: String,
 }
 
-#[derive(Clone, Debug, Default, PartialEq)]
+#[derive(Clone, Debug, Default, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct CacheDir {
     pub prefix: DirPrefix,
     pub path: String,
 }
 
-#[derive(Clone, Debug, Default, PartialEq)]
+#[derive(Clone, Debug, Default, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct Include {
     pub prefix: DirPrefix,
     pub ignore_missing: bool,
     pub path: String,
 }
 
+/// This element contains a directory name where will be mapped as the path 'as-path' in cached information. This is useful if the directory name is an alias (via a bind mount or symlink) to another directory in the system for which cached font information is likely to exist.
+
+/// 'salt' property affects to determine cache filename as same as [`Dir`] element.
+#[derive(Clone, Debug, Default, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
+pub struct RemapDir {
+    pub prefix: DirPrefix,
+    pub as_path: String,
+    pub salt: String,
+    pub path: String,
+}
+
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum DirPrefix {
     Default,
     Cwd,
@@ -52,7 +65,6 @@ macro_rules! define_calculate_path {
             pub const XDG_FALLBACK_PATH: &'static str = $xdg_fallback;
 
             /// Calculate actual path
-            #[cfg(feature = "std")]
             pub fn calculate_path<P: AsRef<std::path::Path> + ?Sized>(
                 &self,
                 config_file_path: &P,
@@ -74,3 +86,4 @@ macro_rules! define_calculate_path {
 define_calculate_path!(Dir, "XDG_DATA_HOME", "~/.local/share");
 define_calculate_path!(CacheDir, "XDG_CACHE_HOME", "~/.cache");
 define_calculate_path!(Include, "XDG_CONFIG_HOME", "~/.config");
+define_calculate_path!(RemapDir, "XDG_CONFIG_HOME", "~/.config");
