@@ -1,6 +1,4 @@
 use crate::{Expression, Value};
-#[cfg(not(feature = "std"))]
-use alloc::string::String;
 
 macro_rules! define_property {
     (
@@ -10,6 +8,7 @@ macro_rules! define_property {
         )+
     ) => {
         #[derive(Clone, Debug, PartialEq)]
+        #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
         pub enum Property {
             $(
                 $(#[$attr])*
@@ -30,6 +29,7 @@ macro_rules! define_property {
         }
 
         #[derive(Clone, Debug, Eq, PartialEq)]
+        #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
         pub enum PropertyKind {
             $(
                 $(#[$attr])*
