@@ -1,21 +1,11 @@
-use crate::{Constant, PropertyKind};
-#[cfg(not(feature = "std"))]
-use alloc::boxed::Box;
-#[cfg(not(feature = "std"))]
-use alloc::string::String;
-#[cfg(not(feature = "std"))]
-use alloc::vec::Vec;
+use crate::{Constant, IntOrRange, PropertyKind};
 
 pub type Bool = bool;
 pub type Int = u32;
 pub type Double = f64;
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub struct CharSet {
-    pub ints: Vec<Int>,
-}
-
 #[derive(Copy, Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum ListOp {
     Times,
     Divide,
@@ -36,16 +26,28 @@ parse_enum! {
 }
 
 #[derive(Copy, Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum UnaryOp {
     Not,
+
+    // these operator not exists in document page but exists in dtd
+    Cecil,
+    Floor,
+    Round,
+    Trunc,
 }
 
 parse_enum! {
     UnaryOp,
     (Not, "not"),
+    (Cecil, "cecil"),
+    (Floor, "floor"),
+    (Round, "round"),
+    (Trunc, "trunc"),
 }
 
 #[derive(Copy, Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum BinaryOp {
     Eq,
     NotEq,
@@ -60,16 +62,17 @@ pub enum BinaryOp {
 parse_enum! {
     BinaryOp,
     (Eq, "eq"),
-    (NotEq, "noteq"),
+    (NotEq, "not_eq"),
     (Less, "less"),
-    (LessEq, "lesseq"),
+    (LessEq, "less_eq"),
     (More, "more"),
-    (MoreEq, "moreeq"),
+    (MoreEq, "more_eq"),
     (Contains, "contains"),
-    (NotContains, "notcontains"),
+    (NotContains, "not_contains"),
 }
 
 #[derive(Copy, Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum TernaryOp {
     If,
 }
@@ -80,16 +83,18 @@ parse_enum! {
 }
 
 #[derive(Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum Expression {
     Simple(Value),
-    Unary(UnaryOp, Vec<Self>),
-    Binary(BinaryOp, Vec<Self>),
-    Ternary(TernaryOp, Vec<Self>),
+    Unary(UnaryOp, Box<Self>),
+    Binary(BinaryOp, Box<[Self; 2]>),
+    Ternary(TernaryOp, Box<[Self; 3]>),
     List(ListOp, Vec<Self>),
-    Matrix(Vec<Self>),
+    Matrix(Box<[Self; 4]>),
 }
 
 #[derive(Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum PropertyTarget {
     Default,
     Font,
@@ -109,21 +114,29 @@ impl Default for PropertyTarget {
     }
 }
 
+pub type CharSet = Vec<IntOrRange>;
+
 /// Runtime typed fontconfig value
 #[derive(Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum Value {
-    /// <int>0</int>
+    /// `<int>0</int>`
     Int(Int),
-    /// <double>1.5</double>
+    /// `<double>1.5</double>`
     Double(Double),
-    /// <string>str</string>
+    /// `<string>str</string>`
     String(String),
+    /// `<const>hintslight</const>`
     Constant(Constant),
-    /// <bool>false</bool>
+    /// `<bool>false</bool>`
     Bool(Bool),
+    /// This element holds the two [`Value::Int`] elements of a range representation.
     Range(Int, Int),
+    /// This element holds at least one [`Value::String`] element of a RFC-3066-style languages or more.
+    LangSet(String),
+    /// This element holds at least one [`Value::Int`] element of an Unicode code point or more.
     CharSet(CharSet),
-    /// <name target="font">pixelsize</name>
+    /// `<name target="font">pixelsize</name>`
     Property(PropertyTarget, PropertyKind),
 }
 
